@@ -1,6 +1,7 @@
 # UTF-8 encoded Russian language file for use with Oddmuse
 #
 # Copyright (c) 2003  Zajcev Evgeny
+# Copyright (C) 2004  Andrei Bulava <abulava@users.sourceforge.net>
 #
 # Permission is granted to copy, distribute and/or modify this
 # document under the terms of the GNU Free Documentation License,
@@ -11,12 +12,11 @@
 #
 # Installation:
 # =============
-# This file should be saved into the same folder where the config file
-# resides.  Load it from the config file:
 #
-# do 'russian-utf8.pl';
+# Create a modules subdirectory in your data directory, and put the
+# file in there. It will be loaded automatically.
 #
-# This script was last checked for Oddmuse version 1.195.
+# This script was last checked for Oddmuse version 1.383.
 #
 %Translate = split('\n',<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
@@ -29,16 +29,18 @@ UserName must be 50 characters or less: not saved
 
 XML::RSS is not available on this system.
 
-LWP::UserAgent is not available on this system.
-
 diff
-
+отличия
 history
+история
+%s returned no data, or LWP::UserAgent is not available.
+
+RSS parsing failed for %s
 
  . . . . 
 
 Click to create this page
-
+Щелчок - создать эту страницу
 http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
 
 http://www.amazon.com/exec/obidos/ISBN=%s
@@ -53,6 +55,8 @@ Invalid action parameter %s
 Некорректный параметр действия %s
 Invalid URL.
 Некорректный URL.
+Page name is missing
+
 Page name is too long: %s
 Имя страницы слишком велико: %s
 Invalid Page %s
@@ -78,7 +82,7 @@ Note: This error is normal if no changes have been made.
 Could not open old %s log file
 Не возможно открыть старый файл протокола %s 
 No updates since %s
-Небыло обновлений с %s
+Не было обновлений с %s
 Updates since %s
 Обновления с %s
 Updates in the last %s days
@@ -88,37 +92,39 @@ Updates in the last %s day
 for %s only
 только для %s
 List latest change per page only
-
-List only major changes
-
-Include minor changes
-
+Перечислить только последнее изменение на страницу
 List all changes
-
+Перечислить все изменения
+List only major changes
+Перечислить только значительные изменения
+Include minor changes
+Включить незначительные изменения
 %s days
 %s дней
 List later changes
-
+Перечислить недавние изменения
 Username:
-
+Имя пользователя:
 Host:
-
+Хост:
 Language:
 
 Filters
-
+Фильтры
 Go!
-
+Вперёд!
 (minor)
-
+(незначительные)
 rollback
+откат
+new
 
 from %s
 с %s
 History of %s
 История %s
 Compare
-
+Сравнить
 Revision %s
 Версия %s
 by
@@ -138,39 +144,9 @@ Rollback to %s
 redirected from %s
 перенаправлено с %s
 Click to search for references to this page
-
+Щелчок - искать ссылки на эту страницу
 Cookie: 
 
-new comment
-
-Save
-Сохранить
-Preview
-Предпросмотр
-Comments on this page
-
-Edit revision %s of this page
-Править версию % этой страницы
-Edit text of this page
-Редактировать текст этой страницы
-This page is read-only
-Эта страница предназначена только для чтения
-View other revisions
-Смотреть другие версии
-View current revision
-Смотреть текущую версию
-View all changes
-
-Back to %s
-
-Last edited
-Последнее редактирование
-Edited
-Правленное
-by %s
-
-(diff)
-(отличия)
 Warning
 Внимание
 Database is stored in temporary directory %s
@@ -181,26 +157,70 @@ The same page on other sites:
 
 EditNearLinks
 
+Last edited
+Последнее редактирование
+Edited
+Правленное
+by %s
+
+(diff)
+(отличия)
+Run maintenance
+
+Unlock site
+
+Lock site
+
+Unlock page
+
+Lock page
+
+Comments on this page
+Комментарии к этой странице
+Edit revision %s of this page
+Править версию %s этой страницы
+Edit text of this page
+Редактировать текст этой страницы
+e
+
+This page is read-only
+Эта страница предназначена только для чтения
+View other revisions
+Смотреть другие версии
+View current revision
+Смотреть текущую версию
+View all changes
+Смотреть все изменения
+Back to %s
+Назад к %s
+new comment
+новый комментарий
+s
+
+Save
+Сохранить
+Preview
+Предпросмотр
 Search:
 Поиск:
 Replace:
-
+Замена:
 Validate HTML
 
 Validate CSS
 
 Difference (from revision %1 to %2)
-
+Отличия (от версии %1 до %2)
 revision %s
-
+версии %s
 current revision
-
+текущей версии
 Difference (from prior %s revision)
 Отличия (текущей версии от предыдущей - %s)
 major
-основной
+значительные
 minor
-второстепенный
+незначительные
 No diff available.
 Отличий нет.
 Changed:
@@ -268,57 +288,57 @@ Editing %s
 Editing old revision %s.
 Редактирование старой версии %s.
 Saving this page will replace the latest revision with this text.
-Сохранение этой страницы заменит последную версию на этот текст.
+Сохранение этой страницы заменит последнюю версию на этот текст.
 Summary:
 Итого:
 This change is a minor edit.
 Это изменение является незначительной правкой.
 Replace this file with text.
-
+Заменить этот файл текстом.
 Replace this text with a file.
-
+Заменить этот текст файлом.
 File to upload: 
 
 Files of type %s are not allowed.
 
 Password
-
+Пароль
 Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
-
+Ваш пароль сохраняется в cookie, если cookies у вас включены. Cookies могут быть потеряны, если вы подключаетесь с другого компьютера, с другой учётной записи, или используя другое программное обеспечение.
 You are currently an administrator on this site.
-
+Теперь вы - администратор на этом сайте.
 You are currently an editor on this site.
-
+Теперь вы - редактор на этом сайте.
 You are a normal user on this site.
-
+Вы - обычный пользователь на этом сайте.
 Your password does not match any of the  administrator or editor passwords.
-
+Ваш пароль не совпадает с паролями администратора или редактора.
 Password:
 Пароль:
 This site does not use admin or editor passwords.
-
+Этот сайт не использует пароли администратора или редактора.
 This operation is restricted to site editors only...
 Эта операция только для редакторов сайта...
 This operation is restricted to administrators only...
 Эта операция только для администаторов сайта...
 Index of all pages
-Проиндексировать все страницы:
+Каталог всех страниц:
 all pages
-
+все страницы
 permanent anchors
-
+неизменные якори
 near links
 
 (for %s)
-
+(%s)
 %s pages found.
-
+Найдено %s страниц.
 Replaced: %s
 
 Search for: %s
 Искать: %s
 View changes for these pages
-
+Смотреть изменения этих страниц
 Search sites on the %s as well
 
 and
@@ -331,8 +351,6 @@ Near pages:
 
 last updated
 
-Full Link List
-Полный список ссылок
 Complete Content
 
 The main page is %s.
@@ -347,7 +365,7 @@ Sample_Undefined_Page
 Пример_Произвольной_Страницы
 [[%s]] cannot be defined.
 [[%s]] невозможно определить
-Only an administrator can create %s
+Only an administrator can create %s.
 
 Transfer Error: %s
 
@@ -355,6 +373,10 @@ Browser reports no file info.
 
 Browser reports no file type.
 
+Edit Denied
+
+The page contains banned text.
+
 This page was changed by somebody else %s.
 
 The changes conflict.  Please check the page again.
@@ -371,10 +393,6 @@ ancestor
 
 other
 
-Ping
-
-No response.
-
 Maintenance on all pages
 
 Maintenance not done.
@@ -387,6 +405,8 @@ Main lock obtained.
 
 Expiring keep files and deleting pages marked for deletion
 
+not deleted: 
+
 deleted
 
 Moving part of the %s log file.
@@ -419,6 +439,8 @@ Near links:
 
 Too many connections by %s
 
+Please do not fetch more than %1 pages in %2 seconds.
+
 Recent Visitors
 
 Referrers
@@ -429,4 +451,86 @@ anchor first defined here: %s
 
 Click to search for references to this permanent anchor
 
+the page %s also exists
+
+Deleting %s
+
+Deleted %s
+
+Renaming %1 to %2.
+
+The page %s does not exist
+
+The page %s already exists
+
+Renamed to %s
+
+Renamed from %s
+
+Renamed %1 to %2.
+
+Delete page
+
+Rename this page to:
+
+Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
+
+The match parameter is missing.
+
+Page Collection for %s
+
+Calendar %s
+
+Footnotes:
+
+image: %s
+
+Languages:
+
+Show!
+
+Define
+
+Full Link List
+Полный список ссылок
+Clearing Cache
+
+Done.
+
+Generating Link Database
+
+The 404 handler extension requires the link data extension (links.pl).
+
+Orphan List
+
+Trail: 
+
+None
+
+Type
+
+Portrait
+
+Thread: %s
+
+ID parameter is missing.
+
+Thread %s does not exist.
+
+Page %s does not contain a thread.
+
+Add
+
+URL parameter is missing.
+
+Add to %s thread
+
+Below:
+
+URL:
+
+Name:
+
+Blog
+
 END_OF_TRANSLATION
